### Introduction
_Vectra API Tools_ is set of resources that is designed to save time and repetitive work by providing a python library that simplifies interaction with the Vectra API, scripts that can be run from the command-line, and additional resources that can help with the Vectra API. It was built to be a project to allow not only Vectra, but the Vectra community to contribute to the success of its customers.

The current repository is broken down into the following:
* _modules_ - this directory contains the modules associated with the VAT library
* _scripts_ - collection of scripts to interact with the Vectra api. These scripts can be used as-is or as a reference on how to leverage the VAT library
* _test_ - collection of tests that can be used to validate the VAT library
* _Vectra\_APIv1.postman\_collection_ is a Postman collection for the Vectra API. It has all of the current endpoints and and associated parameters for each endpoint

**Wiki**  
https://github.com/vectranetworks/vectra_api_tools/wiki

**Current version**  
2.1rc0

**License**  
Apache 2

**Installation**  
pip install from pypi:  
```
pip install vectra_api_tools
```
pip install develop branch from github:
```
pip install git+https://github.com/vectranetworks/vectra_api_tools.git@develop
```
source:
```
python setup.py install
```
